==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QMediaServiceDefaultDeviceInterface_shell.cpp <==
#include "QMediaServiceDefaultDeviceInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QMediaServiceDefaultDeviceInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMediaServiceDefaultDeviceInterface")
    QMediaServiceDefaultDeviceInterface *_ptr = reinterpret_cast<QMediaServiceDefaultDeviceInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QMediaServiceDefaultDeviceInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QMediaServiceDefaultDeviceInterface_shell) ); }

jmethodID QMediaServiceDefaultDeviceInterface_shell::__shell_javaMethod(int pos) const { return QMediaServiceDefaultDeviceInterface_shell::__shell()->javaMethod(typeid(QMediaServiceDefaultDeviceInterface), pos); }

// emitting (writeShellConstructor)
QMediaServiceDefaultDeviceInterface_shell::QMediaServiceDefaultDeviceInterface_shell()
    : QMediaServiceDefaultDeviceInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QMediaServiceDefaultDeviceInterface::QMediaServiceDefaultDeviceInterface_shell()", QMediaServiceDefaultDeviceInterface_shell::__shell())
    QMediaServiceDefaultDeviceInterface_shell::__shell()->constructed(typeid(QMediaServiceDefaultDeviceInterface));
}

// emitting (writeShellDestructor)
QMediaServiceDefaultDeviceInterface_shell::~QMediaServiceDefaultDeviceInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QMediaServiceDefaultDeviceInterface::~QMediaServiceDefaultDeviceInterface()", QMediaServiceDefaultDeviceInterface_shell::__shell())
    QMediaServiceDefaultDeviceInterface_shell::__shell()->destructed(typeid(QMediaServiceDefaultDeviceInterface));
}

void QMediaServiceDefaultDeviceInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QMediaServiceDefaultDeviceInterface_shell*>(ptr)->QMediaServiceDefaultDeviceInterface_shell::__shell()->tryDeleteShell(typeid(QMediaServiceDefaultDeviceInterface));
}

// emitting Virtual overrides (virtualFunctions)
QByteArray QMediaServiceDefaultDeviceInterface_shell::defaultDevice(const QByteArray& service0) const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QMediaServiceDefaultDeviceInterface::", QMediaServiceDefaultDeviceInterface_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QByteArray  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QMediaServiceDefaultDeviceInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_service0 = qtjambi_cast<jobject>(__jni_env, service0);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_service0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QByteArray >(__jni_env, __java_return_value);
                } else {
                    QMediaServiceDefaultDeviceInterface_shell::__shell()->warnForMethod("QMediaServiceDefaultDeviceInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QMediaServiceDefaultDeviceInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QByteArray();
        }
    }else{
        return QByteArray();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QMediaServiceDefaultDeviceInterface_access::__qt_defaultDevice_cref_QByteArray_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID service0) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const QByteArray& __qt_service0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(service0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QMediaServiceDefaultDeviceInterface::defaultDevice(const QByteArray & service) const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QMediaServiceDefaultDeviceInterface::defaultDevice(const QByteArray & service) const.";
    } else {
        QByteArray __qt_return_value = defaultDevice(__qt_service0);
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QMediaServiceDefaultDeviceInterface_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QMediaServiceDefaultDeviceInterface *__qt_this = new(__qtjambi_ptr) QMediaServiceDefaultDeviceInterface_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QMediaServiceDefaultDeviceInterface_shell
void __qt_destruct_QMediaServiceDefaultDeviceInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMediaServiceDefaultDeviceInterface")
    reinterpret_cast<QMediaServiceDefaultDeviceInterface_shell*>(ptr)->~QMediaServiceDefaultDeviceInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMediaServiceDefaultDeviceInterface::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QMediaServiceDefaultDeviceInterface_00024Impl_initialize_1native__Lio_qt_multimedia_QMediaServiceDefaultDeviceInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMediaServiceDefaultDeviceInterface::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMediaServiceDefaultDeviceInterface_0, sizeof(QMediaServiceDefaultDeviceInterface_shell), typeid(QMediaServiceDefaultDeviceInterface), true, &deleter_QMediaServiceDefaultDeviceInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMediaServiceDefaultDeviceInterface::defaultDevice(QByteArray)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QMediaServiceDefaultDeviceInterface_00024Impl_00024ConcreteWrapper_defaultDevice_1native_1cref_1QByteArray_1constfct__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID service0)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMediaServiceDefaultDeviceInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QMediaServiceDefaultDeviceInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMediaServiceDefaultDeviceInterface::defaultDevice(QByteArray)const", __qt_this)
        __java_return_value = static_cast<const QMediaServiceDefaultDeviceInterface_access*>(__qt_this)->__qt_defaultDevice_cref_QByteArray_constfct(__jni_env, __this_nativeId, service0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QMediaServiceDefaultDeviceInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QMediaServiceDefaultDeviceInterface>("QMediaServiceDefaultDeviceInterface", "io/qt/multimedia/QMediaServiceDefaultDeviceInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "defaultDevice", "(Lio/qt/core/QByteArray;)Lio/qt/core/QByteArray;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QMediaServiceDefaultDeviceInterface, {
        ConstructorInfo(&__qt_construct_QMediaServiceDefaultDeviceInterface_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMediaServiceDefaultDeviceInterface);
    registerSizeOfShell(typeId, sizeof(QMediaServiceDefaultDeviceInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QMediaServiceDefaultDeviceInterface* _object = dynamic_cast<QMediaServiceDefaultDeviceInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QMediaServiceDefaultDeviceInterface *object = reinterpret_cast<QMediaServiceDefaultDeviceInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QMediaServiceDefaultDeviceInterface *object = reinterpret_cast<const QMediaServiceDefaultDeviceInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QMediaServiceDefaultDeviceInterface_shell.cpp <==
#include "QMediaServiceDefaultDeviceInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QMediaServiceDefaultDeviceInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMediaServiceDefaultDeviceInterface")
    QMediaServiceDefaultDeviceInterface *_ptr = reinterpret_cast<QMediaServiceDefaultDeviceInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QMediaServiceDefaultDeviceInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QMediaServiceDefaultDeviceInterface_shell) ); }

jmethodID QMediaServiceDefaultDeviceInterface_shell::__shell_javaMethod(int pos) const { return QMediaServiceDefaultDeviceInterface_shell::__shell()->javaMethod(typeid(QMediaServiceDefaultDeviceInterface), pos); }

// emitting (writeShellConstructor)
QMediaServiceDefaultDeviceInterface_shell::QMediaServiceDefaultDeviceInterface_shell()
    : QMediaServiceDefaultDeviceInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QMediaServiceDefaultDeviceInterface::QMediaServiceDefaultDeviceInterface_shell()", QMediaServiceDefaultDeviceInterface_shell::__shell())
    QMediaServiceDefaultDeviceInterface_shell::__shell()->constructed(typeid(QMediaServiceDefaultDeviceInterface));
}

// emitting (writeShellDestructor)
QMediaServiceDefaultDeviceInterface_shell::~QMediaServiceDefaultDeviceInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QMediaServiceDefaultDeviceInterface::~QMediaServiceDefaultDeviceInterface()", QMediaServiceDefaultDeviceInterface_shell::__shell())
    QMediaServiceDefaultDeviceInterface_shell::__shell()->destructed(typeid(QMediaServiceDefaultDeviceInterface));
}

void QMediaServiceDefaultDeviceInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QMediaServiceDefaultDeviceInterface_shell*>(ptr)->QMediaServiceDefaultDeviceInterface_shell::__shell()->tryDeleteShell(typeid(QMediaServiceDefaultDeviceInterface));
}

// emitting Virtual overrides (virtualFunctions)
QByteArray QMediaServiceDefaultDeviceInterface_shell::defaultDevice(const QByteArray& service0) const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QMediaServiceDefaultDeviceInterface::", QMediaServiceDefaultDeviceInterface_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QByteArray  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QMediaServiceDefaultDeviceInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_service0 = qtjambi_cast<jobject>(__jni_env, service0);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_service0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QByteArray >(__jni_env, __java_return_value);
                } else {
                    QMediaServiceDefaultDeviceInterface_shell::__shell()->warnForMethod("QMediaServiceDefaultDeviceInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QMediaServiceDefaultDeviceInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QByteArray();
        }
    }else{
        return QByteArray();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QMediaServiceDefaultDeviceInterface_access::__qt_defaultDevice_cref_QByteArray_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID service0) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const QByteArray& __qt_service0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(service0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QMediaServiceDefaultDeviceInterface::defaultDevice(const QByteArray & service) const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QMediaServiceDefaultDeviceInterface::defaultDevice(const QByteArray & service) const.";
    } else {
        QByteArray __qt_return_value = defaultDevice(__qt_service0);
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QMediaServiceDefaultDeviceInterface()
void __qt_construct_QMediaServiceDefaultDeviceInterface(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMediaServiceDefaultDeviceInterface()")
    Q_UNUSED(__java_arguments)
    QMediaServiceDefaultDeviceInterface *__qt_this = new(__qtjambi_ptr) QMediaServiceDefaultDeviceInterface_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QMediaServiceDefaultDeviceInterface::QMediaServiceDefaultDeviceInterface()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QMediaServiceDefaultDeviceInterface_00024Impl_initialize_1native__Lio_qt_multimedia_QMediaServiceDefaultDeviceInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMediaServiceDefaultDeviceInterface::QMediaServiceDefaultDeviceInterface()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMediaServiceDefaultDeviceInterface, sizeof(QMediaServiceDefaultDeviceInterface_shell), typeid(QMediaServiceDefaultDeviceInterface), true, &deleter_QMediaServiceDefaultDeviceInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QMediaServiceDefaultDeviceInterface_shell
void __qt_destruct_QMediaServiceDefaultDeviceInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMediaServiceDefaultDeviceInterface")
    reinterpret_cast<QMediaServiceDefaultDeviceInterface_shell*>(ptr)->~QMediaServiceDefaultDeviceInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMediaServiceDefaultDeviceInterface::defaultDevice(QByteArray)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QMediaServiceDefaultDeviceInterface_00024Impl_00024ConcreteWrapper_defaultDevice_1native_1cref_1QByteArray_1constfct__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID service0)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMediaServiceDefaultDeviceInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QMediaServiceDefaultDeviceInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMediaServiceDefaultDeviceInterface::defaultDevice(QByteArray)const", __qt_this)
        __java_return_value = static_cast<const QMediaServiceDefaultDeviceInterface_access*>(__qt_this)->__qt_defaultDevice_cref_QByteArray_constfct(__jni_env, __this_nativeId, service0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QMediaServiceDefaultDeviceInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QMediaServiceDefaultDeviceInterface>("QMediaServiceDefaultDeviceInterface", "io/qt/multimedia/QMediaServiceDefaultDeviceInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "defaultDevice", "(Lio/qt/core/QByteArray;)Lio/qt/core/QByteArray;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QMediaServiceDefaultDeviceInterface, {
        ConstructorInfo(&__qt_construct_QMediaServiceDefaultDeviceInterface, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMediaServiceDefaultDeviceInterface);
    registerSizeOfShell(typeId, sizeof(QMediaServiceDefaultDeviceInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QMediaServiceDefaultDeviceInterface* _object = dynamic_cast<QMediaServiceDefaultDeviceInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QMediaServiceDefaultDeviceInterface *object = reinterpret_cast<QMediaServiceDefaultDeviceInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QMediaServiceDefaultDeviceInterface *object = reinterpret_cast<const QMediaServiceDefaultDeviceInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
